@@ -18,6 +18,7 @@
 #include "plugin_p.h"
 #include "process_p.h"
 #include "screensaver_p.h"
+#include "screenshot_p.h"
 #include "settings_p.h"
 
 void Plugin::registerTypes(const char *uri) {
@@ -25,6 +26,7 @@ void Plugin::registerTypes(const char *uri) {
 
     qmlRegisterType<Process>(uri, 1, 0, "Process");
     qmlRegisterType<ScreenSaver>(uri, 1, 0, "ScreenSaver");
+    qmlRegisterType<ScreenShot>(uri, 1, 0, "ScreenShot");
     qmlRegisterType<Settings>(uri, 1, 0, "Settings");
 }
 
